/****************************************************************************
 *
 * Copyright (c) 2010-2012, EBM WebSourcing
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
 *
 *****************************************************************************/
 
package org.ow2.petals.develpment.enforcer.rules;

import org.apache.maven.enforcer.rule.api.EnforcerRuleException;
import org.apache.maven.enforcer.rule.api.EnforcerRuleHelper;
import org.apache.maven.project.MavenProject;
import org.codehaus.plexus.component.configurator.expression.ExpressionEvaluationException;

public class ScmConnectionMustMatchSvnEntriesIfAny extends AbstractRule {

    // Not final because set by injection
    private boolean shouldIFail = false;

    public void doExecute(EnforcerRuleHelper helper) throws EnforcerRuleException {

        final MavenProject mavenProject;
        try {
            mavenProject = (MavenProject) helper.evaluate("${project}");
        } catch (final ExpressionEvaluationException e) {
            throw new EnforcerRuleException("Unable to evaluate the current maven project", e);
        }

        final String expectedScmConnection = SvnUtil.grepScmConnectionFromSvnEntries(mavenProject);
        if (expectedScmConnection == null) {
            helper.getLog().info(".svn/entries file is not present or not readable ; rule ignored.");
            return;
        }

        final String actualScmConnection;
        try {
            actualScmConnection = String.valueOf(helper.evaluate("${project.scm.connection}"));
        } catch (ExpressionEvaluationException e) {
            throw new EnforcerRuleException("Unable to evaluate the SCM connection", e);
        }

        if (!expectedScmConnection.equals(actualScmConnection)) {
            final String message = String.format("Wrong SCM connection '%s' ; '%s' was expected.",
                    actualScmConnection, expectedScmConnection);
            if (this.shouldIFail) {
                throw new EnforcerRuleException(message);
            }
        }
    }

}
